MethodChannelFacePlugin class

An implementation of FacePluginPlatform that uses method channels.

Inheritance

Constructors

MethodChannelFacePlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectFaces(Uint8List imageBytes) Future<List<Face>>
override
extractFeatures(Uint8List imageBytes) Future<List<List<double>>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited