FacePluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FacePluginPlatform
Implementers

Constructors

FacePluginPlatform()
Constructs a FacePluginPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectFaces(Uint8List imageBytes) Future<List<Face>>
extractFeatures(Uint8List imageBytes) Future<List<List<double>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FacePluginPlatform
The default instance of FacePluginPlatform to use.
getter/setter pair